![Publish cryptlex.lexfloatclient package](https://github.com/cryptlex/lexfloatclient-python/workflows/Publish%20cryptlex.lexfloatclient%20package/badge.svg)

# cryptlex.lexfloatclient

Cryptlex lets you license your software apps effortlessly. You can easily generate license keys using the REST API or Dashboard and validate the license keys in your software apps using LexActivator (Cryptlex client library), implement floating licenses using LexFloatClient library.

Additionally, you can offer trials, subscriptions, floating licenses and much more.

**cryptlex.lexfloatclient** is a Python wrapper for LexFloatClient licensing library.

## Installation

    pip install cryptlex.lexfloatclient

Then you can include it in your code:

	from cryptlex.lexfloatclient import LexFloatClient, LexFloatStatusCodes, LexFloatClientException


## Usage
Refer to following for documentation:

https://docs.cryptlex.com/floating-licenses/on-premise-floating-licenses/using-lexfloatclient/using-lexfloatclient-with-python